@@ -16,9 +16,9 @@ import logging
 
 from django.template import defaultfilters as filters
 from django.urls import reverse
+from django.utils.translation import gettext_lazy as _
+from django.utils.translation import ngettext_lazy
 from django.utils.translation import pgettext_lazy
-from django.utils.translation import ugettext_lazy as _
-from django.utils.translation import ungettext_lazy
 from neutronclient.common import exceptions as neutron_exceptions
 
 from horizon import exceptions
@@ -36,7 +36,7 @@ LOG = logging.getLogger(__name__)
 class DeleteRouter(policy.PolicyTargetMixin, tables.DeleteAction):
     @staticmethod
     def action_present(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             "Delete Router",
             "Delete Routers",
             count
@@ -44,7 +44,7 @@ class DeleteRouter(policy.PolicyTargetMixin, tables.DeleteAction):
 
     @staticmethod
     def action_past(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             "Deleted Router",
             "Deleted Routers",
             count
@@ -127,7 +127,7 @@ class ClearGateway(policy.PolicyTargetMixin, tables.BatchAction):
 
     @staticmethod
     def action_present(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             "Clear Gateway",
             "Clear Gateways",
             count
@@ -135,7 +135,7 @@ class ClearGateway(policy.PolicyTargetMixin, tables.BatchAction):
 
     @staticmethod
     def action_past(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             "Cleared Gateway",
             "Cleared Gateways",
             count
